@@ -210,7 +210,7 @@ do_eject (const char *object_path,
   proxy = dbus_g_proxy_new_for_name (bus, "org.freedesktop.UDisks", object_path, "org.freedesktop.UDisks.Device");
 
   error = NULL;
-  if (!org_freedesktop_UDisks_Device_drive_eject (proxy, (const char **) options, &error))
+  if (!org_freedesktop_UDisks_Device_drive_eject (proxy, (const char **) eject_options, &error))
     {
       g_print ("Eject failed: %s\n", error->message);
       g_error_free (error);
@@ -348,6 +348,7 @@ typedef struct
   gboolean device_presentation_nopolicy;
   char *device_presentation_name;
   char *device_presentation_icon_name;
+  char *device_automount_hint;
   guint64 device_size;
   guint64 device_block_size;
 
@@ -545,6 +546,8 @@ collect_props (const char *key,
     props->device_presentation_name = g_strdup (g_value_get_string (value));
   else if (strcmp (key, "DevicePresentationIconName") == 0)
     props->device_presentation_icon_name = g_strdup (g_value_get_string (value));
+  else if (strcmp (key, "DeviceAutomountHint") == 0)
+    props->device_automount_hint = g_strdup (g_value_get_string (value));
   else if (strcmp (key, "DeviceSize") == 0)
     props->device_size = g_value_get_uint64 (value);
   else if (strcmp (key, "DeviceBlockSize") == 0)
@@ -815,6 +818,7 @@ device_properties_free (DeviceProperties *props)
   g_strfreev (props->device_mount_paths);
   g_free (props->device_presentation_name);
   g_free (props->device_presentation_icon_name);
+  g_free (props->device_automount_hint);
   g_free (props->job_id);
   g_free (props->id_usage);
   g_free (props->id_type);
@@ -931,12 +935,8 @@ device_properties_get (DBusGConnection *bus,
 static gboolean
 do_monitor (void)
 {
-  GError *error;
-
   g_print ("Monitoring activity from the disks daemon. Press Ctrl+C to cancel.\n");
 
-  error = NULL;
-
   dbus_g_proxy_connect_signal (disks_proxy, "DeviceAdded", G_CALLBACK (device_added_signal_handler), NULL, NULL);
   dbus_g_proxy_connect_signal (disks_proxy, "DeviceRemoved", G_CALLBACK (device_removed_signal_handler), NULL, NULL);
   dbus_g_proxy_connect_signal (disks_proxy, "DeviceChanged", G_CALLBACK (device_changed_signal_handler), NULL, NULL);
@@ -1225,6 +1225,7 @@ do_show_info (const char *object_path)
   g_print ("  presentation nopolicy:       %d\n", props->device_presentation_nopolicy);
   g_print ("  presentation name:           %s\n", props->device_presentation_name);
   g_print ("  presentation icon:           %s\n", props->device_presentation_icon_name);
+  g_print ("  automount hint:              %s\n", props->device_automount_hint);
   g_print ("  size:                        %" G_GUINT64_FORMAT "\n", props->device_size);
   g_print ("  block size:                  %" G_GUINT64_FORMAT "\n", props->device_block_size);
 
